==> jasperserver-2.1.0-src.zip: jasperserver-2.1.0-src/jasperserver/jasperserver-export-tool/src/main/java/com/jaspersoft/jasperserver/export/io/BaseExportOutput.java <==
/*
 * Copyright (C) 2007 JasperSoft http://www.jaspersoft.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; and without the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt 
 * or write to:
 * 
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */

package com.jaspersoft.jasperserver.export.io;

import java.io.IOException;
import java.io.OutputStream;

import com.jaspersoft.jasperserver.export.util.PathUtils;


/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: BaseExportOutput.java 8408 2007-05-29 23:29:12Z melih $
 */
public abstract class BaseExportOutput implements ExportOutput {

	public String mkdir(String parentPath, String path) throws IOException {
		String fullPath = PathUtils.concatPaths(parentPath, path);
		mkdir(fullPath);
		return fullPath;
	}

	public OutputStream getFileOutputStream(String parentPath, String path) throws IOException {
		return getFileOutputStream(PathUtils.concatPaths(parentPath, path));
	}

}

==> jasperserver-3.5.0-src.zip: jasperserver-3.5.0-src/jasperserver/jasperserver-export-tool/src/main/java/com/jaspersoft/jasperserver/export/io/BaseExportOutput.java <==
/*
 * Copyright (C) 2007 JasperSoft http://www.jaspersoft.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; and without the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt 
 * or write to:
 * 
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */

package com.jaspersoft.jasperserver.export.io;

import java.io.IOException;
import java.io.OutputStream;
import java.util.Properties;

import com.jaspersoft.jasperserver.export.util.PathUtils;


/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: BaseExportOutput.java 12510 2008-03-14 15:20:13Z lucian $
 */
public abstract class BaseExportOutput implements ExportOutput {

	private Properties outputProperties;
	
	protected BaseExportOutput() {
		this(new Properties());
	}
	
	protected BaseExportOutput(Properties outputProperties) {
		this.outputProperties = outputProperties;
	}
	
	public String mkdir(String parentPath, String path) throws IOException {
		String fullPath = PathUtils.concatPaths(parentPath, path);
		mkdir(fullPath);
		return fullPath;
	}

	public OutputStream getFileOutputStream(String parentPath, String path) throws IOException {
		return getFileOutputStream(PathUtils.concatPaths(parentPath, path));
	}

	public Properties getOutputProperties() {
		return outputProperties;
	}

}
